@@ -1,6 +1,5 @@
 import base64
 import logging
-from typing import Dict
 from unittest.mock import MagicMock, patch
 
 import pytest
@@ -10,6 +9,7 @@ from huggingface_hub.hf_api import InferenceProviderMapping
 from huggingface_hub.inference._common import RequestParameters
 from huggingface_hub.inference._providers import PROVIDERS, get_provider_helper
 from huggingface_hub.inference._providers._common import (
+    AutoRouterConversationalTask,
     BaseConversationalTask,
     BaseTextGenerationTask,
     TaskProviderHelper,
@@ -17,11 +17,14 @@ from huggingface_hub.inference._providers._common import (
     recursive_merge,
 )
 from huggingface_hub.inference._providers.black_forest_labs import BlackForestLabsTextToImageTask
+from huggingface_hub.inference._providers.clarifai import ClarifaiConversationalTask
 from huggingface_hub.inference._providers.cohere import CohereConversationalTask
 from huggingface_hub.inference._providers.fal_ai import (
     _POLLING_INTERVAL,
     FalAIAutomaticSpeechRecognitionTask,
+    FalAIImageSegmentationTask,
     FalAIImageToImageTask,
+    FalAIImageToVideoTask,
     FalAITextToImageTask,
     FalAITextToSpeechTask,
     FalAITextToVideoTask,
@@ -43,13 +46,22 @@ from huggingface_hub.inference._providers.nebius import NebiusFeatureExtractionT
 from huggingface_hub.inference._providers.novita import NovitaConversationalTask, NovitaTextGenerationTask
 from huggingface_hub.inference._providers.nscale import NscaleConversationalTask, NscaleTextToImageTask
 from huggingface_hub.inference._providers.openai import OpenAIConversationalTask
+from huggingface_hub.inference._providers.publicai import PublicAIConversationalTask
 from huggingface_hub.inference._providers.replicate import (
     ReplicateImageToImageTask,
     ReplicateTask,
     ReplicateTextToSpeechTask,
 )
 from huggingface_hub.inference._providers.sambanova import SambanovaConversationalTask, SambanovaFeatureExtractionTask
+from huggingface_hub.inference._providers.scaleway import ScalewayConversationalTask, ScalewayFeatureExtractionTask
 from huggingface_hub.inference._providers.together import TogetherTextToImageTask
+from huggingface_hub.inference._providers.wavespeed import (
+    WavespeedAIImageToImageTask,
+    WavespeedAIImageToVideoTask,
+    WavespeedAITextToImageTask,
+    WavespeedAITextToVideoTask,
+)
+from huggingface_hub.inference._providers.zai_org import ZaiConversationalTask
 
 from .testing_utils import assert_in_logs
 
@@ -190,6 +202,47 @@ class TestBasicTaskProviderHelper:
         helper._prepare_route.assert_called_once_with("test-model", "sk_test_token")
 
 
+class TestAutoRouterConversationalTask:
+    def test_properties(self):
+        helper = AutoRouterConversationalTask()
+        assert helper.provider == "auto"
+        assert helper.base_url == "https://router.huggingface.co"
+        assert helper.task == "conversational"
+
+    def test_prepare_mapping_info_is_fake(self):
+        helper = AutoRouterConversationalTask()
+        mapping_info = helper._prepare_mapping_info("test-model")
+        assert mapping_info.hf_model_id == "test-model"
+        assert mapping_info.provider_id == "test-model"
+        assert mapping_info.task == "conversational"
+        assert mapping_info.status == "live"
+
+    def test_prepare_request(self):
+        helper = AutoRouterConversationalTask()
+
+        request = helper.prepare_request(
+            inputs=[{"role": "user", "content": "Hello!"}],
+            parameters={"model": "test-model", "frequency_penalty": 1.0},
+            headers={},
+            model="test-model",
+            api_key="hf_test_token",
+        )
+
+        # Use auto-router URL
+        assert request.url == "https://router.huggingface.co/v1/chat/completions"
+
+        # The rest is the expected request for a Chat Completion API
+        assert request.headers["authorization"] == "Bearer hf_test_token"
+        assert request.json == {
+            "messages": [{"role": "user", "content": "Hello!"}],
+            "model": "test-model",
+            "frequency_penalty": 1.0,
+        }
+        assert request.task == "conversational"
+        assert request.model == "test-model"
+        assert request.data is None
+
+
 class TestBlackForestLabsProvider:
     def test_prepare_headers_bfl_key(self):
         helper = BlackForestLabsTextToImageTask()
@@ -289,6 +342,34 @@ class TestCohereConversationalTask:
         }
 
 
+class TestClarifaiProvider:
+    def test_prepare_url(self):
+        helper = ClarifaiConversationalTask()
+        assert (
+            helper._prepare_url("clarifai_api_key", "username/repo_name")
+            == "https://api.clarifai.com/v2/ext/openai/v1/chat/completions"
+        )
+
+    def test_prepare_payload_as_dict(self):
+        helper = ClarifaiConversationalTask()
+        payload = helper._prepare_payload_as_dict(
+            [{"role": "user", "content": "Hello!"}],
+            {},
+            InferenceProviderMapping(
+                provider="clarifai",
+                hf_model_id="meta-llama/llama-3.1-8B-Instruct",
+                providerId="meta-llama/llama-3.1-8B-Instruct",
+                task="conversational",
+                status="live",
+            ),
+        )
+
+        assert payload == {
+            "messages": [{"role": "user", "content": "Hello!"}],
+            "model": "meta-llama/llama-3.1-8B-Instruct",
+        }
+
+
 class TestFalAIProvider:
     def test_prepare_headers_fal_ai_key(self):
         """When using direct call, must use Key authorization."""
@@ -476,6 +557,197 @@ class TestFalAIProvider:
         mock_sleep.assert_called_once_with(_POLLING_INTERVAL)
         assert response == b"image_content"
 
+    def test_image_to_video_payload(self):
+        helper = FalAIImageToVideoTask()
+        mapping_info = InferenceProviderMapping(
+            provider="fal-ai",
+            hf_model_id="Wan-AI/Wan2.2-I2V-A14B",
+            providerId="Wan-AI/Wan2.2-I2V-A14B",
+            task="image-to-video",
+            status="live",
+        )
+        payload = helper._prepare_payload_as_dict(
+            "https://example.com/image.png",
+            {"prompt": "a cat"},
+            mapping_info,
+        )
+        assert payload == {"image_url": "https://example.com/image.png", "prompt": "a cat"}
+
+        payload = helper._prepare_payload_as_dict(
+            b"dummy_image_data",
+            {"prompt": "a dog"},
+            mapping_info,
+        )
+        assert payload == {
+            "image_url": f"data:image/jpeg;base64,{base64.b64encode(b'dummy_image_data').decode()}",
+            "prompt": "a dog",
+        }
+
+    def test_image_to_video_response(self, mocker):
+        helper = FalAIImageToVideoTask()
+        mock_session = mocker.patch("huggingface_hub.inference._providers.fal_ai.get_session")
+        mock_sleep = mocker.patch("huggingface_hub.inference._providers.fal_ai.time.sleep")
+        mock_session.return_value.get.side_effect = [
+            # First call: status
+            mocker.Mock(json=lambda: {"status": "COMPLETED"}, headers={"Content-Type": "application/json"}),
+            # Second call: get result
+            mocker.Mock(json=lambda: {"video": {"url": "video_url"}}, headers={"Content-Type": "application/json"}),
+            # Third call: get video content
+            mocker.Mock(content=b"video_content"),
+        ]
+        api_key = helper._prepare_api_key("hf_token")
+        headers = helper._prepare_headers({}, api_key)
+        url = helper._prepare_url(api_key, "username/repo_name")
+
+        request_params = RequestParameters(
+            url=url,
+            headers=headers,
+            task="image-to-video",
+            model="username/repo_name",
+            data=None,
+            json=None,
+        )
+        response = helper.get_response(
+            b'{"request_id": "test_request_id", "status": "PROCESSING", "response_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id", "status_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id/status"}',
+            request_params,
+        )
+
+        # Verify the correct URLs were called
+        assert mock_session.return_value.get.call_count == 3
+        mock_session.return_value.get.assert_has_calls(
+            [
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id/status?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+                mocker.call("video_url"),
+            ]
+        )
+        mock_sleep.assert_called_once_with(_POLLING_INTERVAL)
+        assert response == b"video_content"
+
+    def test_image_segmentation_payload(self):
+        helper = FalAIImageSegmentationTask()
+        mapping_info = InferenceProviderMapping(
+            provider="fal-ai",
+            hf_model_id="briaai/RMBG-2.0",
+            providerId="fal-ai/rmbg-2.0",
+            task="image-segmentation",
+            status="live",
+        )
+        payload = helper._prepare_payload_as_dict("https://example.com/image.png", {"threshold": 0.5}, mapping_info)
+        assert payload == {"image_url": "https://example.com/image.png", "threshold": 0.5, "sync_mode": True}
+
+        payload = helper._prepare_payload_as_dict(b"dummy_image_data", {"mask_threshold": 0.8}, mapping_info)
+        assert payload == {
+            "image_url": f"data:image/png;base64,{base64.b64encode(b'dummy_image_data').decode()}",
+            "mask_threshold": 0.8,
+            "sync_mode": True,
+        }
+
+    def test_image_segmentation_response_with_data_url(self, mocker):
+        """Test image segmentation response when image URL is a data URL."""
+        helper = FalAIImageSegmentationTask()
+        mock_session = mocker.patch("huggingface_hub.inference._providers.fal_ai.get_session")
+        mock_sleep = mocker.patch("huggingface_hub.inference._providers.fal_ai.time.sleep")
+        dummy_mask_base64 = base64.b64encode(b"mask_content").decode()
+        data_url = f"data:image/png;base64,{dummy_mask_base64}"
+        mock_session.return_value.get.side_effect = [
+            # First call: status
+            mocker.Mock(json=lambda: {"status": "COMPLETED"}, headers={"Content-Type": "application/json"}),
+            # Second call: get result
+            mocker.Mock(json=lambda: {"image": {"url": data_url}}, headers={"Content-Type": "application/json"}),
+        ]
+        api_key = helper._prepare_api_key("hf_token")
+        headers = helper._prepare_headers({}, api_key)
+        url = helper._prepare_url(api_key, "username/repo_name")
+
+        request_params = RequestParameters(
+            url=url,
+            headers=headers,
+            task="image-segmentation",
+            model="username/repo_name",
+            data=None,
+            json=None,
+        )
+        response = helper.get_response(
+            b'{"request_id": "test_request_id", "status": "PROCESSING", "response_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id", "status_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id/status"}',
+            request_params,
+        )
+
+        # Verify the correct URLs were called (only status and result, no fetch needed for data URL)
+        assert mock_session.return_value.get.call_count == 2
+        mock_session.return_value.get.assert_has_calls(
+            [
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id/status?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+            ]
+        )
+        mock_sleep.assert_called_once_with(_POLLING_INTERVAL)
+        assert response == [{"label": "mask", "mask": dummy_mask_base64}]
+
+    def test_image_segmentation_response_with_regular_url(self, mocker):
+        """Test image segmentation response when image URL is a regular HTTP URL."""
+        helper = FalAIImageSegmentationTask()
+        mock_session = mocker.patch("huggingface_hub.inference._providers.fal_ai.get_session")
+        mock_sleep = mocker.patch("huggingface_hub.inference._providers.fal_ai.time.sleep")
+        dummy_mask_base64 = base64.b64encode(b"mask_content").decode()
+        mock_session.return_value.get.side_effect = [
+            # First call: status
+            mocker.Mock(json=lambda: {"status": "COMPLETED"}, headers={"Content-Type": "application/json"}),
+            # Second call: get result
+            mocker.Mock(
+                json=lambda: {"image": {"url": "https://example.com/mask.png"}},
+                headers={"Content-Type": "application/json"},
+            ),
+            # Third call: get mask content
+            mocker.Mock(content=b"mask_content", raise_for_status=lambda: None),
+        ]
+        api_key = helper._prepare_api_key("hf_token")
+        headers = helper._prepare_headers({}, api_key)
+        url = helper._prepare_url(api_key, "username/repo_name")
+
+        request_params = RequestParameters(
+            url=url,
+            headers=headers,
+            task="image-segmentation",
+            model="username/repo_name",
+            data=None,
+            json=None,
+        )
+        response = helper.get_response(
+            b'{"request_id": "test_request_id", "status": "PROCESSING", "response_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id", "status_url": "https://queue.fal.run/username_provider/repo_name_provider/requests/test_request_id/status"}',
+            request_params,
+        )
+
+        # Verify the correct URLs were called (status, result, and mask fetch)
+        assert mock_session.return_value.get.call_count == 3
+        mock_session.return_value.get.assert_has_calls(
+            [
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id/status?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+                mocker.call(
+                    "https://router.huggingface.co/fal-ai/username_provider/repo_name_provider/requests/test_request_id?_subdomain=queue",
+                    headers=request_params.headers,
+                ),
+                mocker.call("https://example.com/mask.png"),
+            ]
+        )
+        mock_sleep.assert_called_once_with(_POLLING_INTERVAL)
+        assert response == [{"label": "mask", "mask": dummy_mask_base64}]
+
 
 class TestFeatherlessAIProvider:
     def test_prepare_route_chat_completionurl(self):
@@ -840,6 +1112,31 @@ class TestHFInferenceProvider:
         else:
             _check_supported_task("test-model", task)
 
+    def test_prepare_request_from_binary_data(self, mocker, tmp_path):
+        helper = HFInferenceBinaryInputTask("image-classification")
+
+        mock_model_info = mocker.Mock(pipeline_tag="image-classification", tags=[])
+        mocker.patch("huggingface_hub.hf_api.HfApi.model_info", return_value=mock_model_info)
+
+        image_path = tmp_path / "image.jpg"
+        image_path.write_bytes(b"dummy binary input")
+
+        request = helper.prepare_request(
+            inputs=image_path,
+            parameters={},
+            headers={},
+            model="microsoft/resnet-50",
+            api_key="hf_test_token",
+            extra_payload=None,
+        )
+        assert request.url == "https://router.huggingface.co/hf-inference/models/microsoft/resnet-50"
+        assert request.task == "image-classification"
+        assert request.model == "microsoft/resnet-50"
+        assert request.json is None
+        assert isinstance(request.data, bytes)
+        assert request.headers["authorization"] == "Bearer hf_test_token"
+        assert request.headers["content-type"] == "image/jpeg"  # based on filename
+
 
 class TestHyperbolicProvider:
     def test_prepare_route(self):
@@ -978,6 +1275,84 @@ class TestNovitaProvider:
         assert url == "https://api.novita.ai/v3/openai/chat/completions"
 
 
+class TestScalewayProvider:
+    def test_prepare_hf_url_conversational(self):
+        helper = ScalewayConversationalTask()
+        url = helper._prepare_url("hf_token", "username/repo_name")
+        assert url == "https://router.huggingface.co/scaleway/v1/chat/completions"
+
+    def test_prepare_url_conversational(self):
+        helper = ScalewayConversationalTask()
+        url = helper._prepare_url("scw_token", "username/repo_name")
+        assert url == "https://api.scaleway.ai/v1/chat/completions"
+
+    def test_prepare_payload_as_dict(self):
+        helper = ScalewayConversationalTask()
+        payload = helper._prepare_payload_as_dict(
+            [
+                {"role": "system", "content": "You are a helpful assistant"},
+                {"role": "user", "content": "Hello!"},
+            ],
+            {
+                "max_tokens": 512,
+                "temperature": 0.15,
+                "top_p": 1,
+                "presence_penalty": 0,
+                "stream": True,
+            },
+            InferenceProviderMapping(
+                provider="scaleway",
+                hf_model_id="meta-llama/Llama-3.1-8B-Instruct",
+                providerId="meta-llama/llama-3.1-8B-Instruct",
+                task="conversational",
+                status="live",
+            ),
+        )
+        assert payload == {
+            "max_tokens": 512,
+            "messages": [
+                {"content": "You are a helpful assistant", "role": "system"},
+                {"role": "user", "content": "Hello!"},
+            ],
+            "model": "meta-llama/llama-3.1-8B-Instruct",
+            "presence_penalty": 0,
+            "stream": True,
+            "temperature": 0.15,
+            "top_p": 1,
+        }
+
+    def test_prepare_url_feature_extraction(self):
+        helper = ScalewayFeatureExtractionTask()
+        assert (
+            helper._prepare_url("hf_token", "username/repo_name")
+            == "https://router.huggingface.co/scaleway/v1/embeddings"
+        )
+
+    def test_prepare_payload_as_dict_feature_extraction(self):
+        helper = ScalewayFeatureExtractionTask()
+        payload = helper._prepare_payload_as_dict(
+            "Example text to embed",
+            {"truncate": True},
+            InferenceProviderMapping(
+                provider="scaleway",
+                hf_model_id="username/repo_name",
+                providerId="provider-id",
+                task="feature-extraction",
+                status="live",
+            ),
+        )
+        assert payload == {"input": "Example text to embed", "model": "provider-id", "truncate": True}
+
+
+class TestPublicAIProvider:
+    def test_prepare_url(self):
+        helper = PublicAIConversationalTask()
+        assert (
+            helper._prepare_url("publicai_token", "username/repo_name")
+            == "https://api.publicai.co/v1/chat/completions"
+        )
+
+
 class TestNscaleProvider:
     def test_prepare_route_text_to_image(self):
         helper = NscaleTextToImageTask()
@@ -1233,6 +1608,188 @@ class TestTogetherProvider:
         assert response == b"image_bytes"
 
 
+class TestWavespeedAIProvider:
+    """Test Wavespeed AI provider functionality."""
+
+    def test_prepare_headers(self):
+        """Test header preparation for both direct and routed calls."""
+        helper = WavespeedAITextToImageTask()
+
+        # Test with Wavespeed API key
+        headers = helper._prepare_headers({}, "ws_test_key")
+        assert headers["authorization"] == "Bearer ws_test_key"
+
+        # Test with HF token
+        headers = helper._prepare_headers({}, "hf_token")
+        assert headers["authorization"] == "Bearer hf_token"
+
+    def test_prepare_text_to_image_payload(self):
+        """Test payload preparation for text-to-image task."""
+        helper = WavespeedAITextToImageTask()
+        payload = helper._prepare_payload_as_dict(
+            "a beautiful cat",
+            {
+                "num_inference_steps": 30,
+                "guidance_scale": 7.5,
+                "width": 512,
+                "height": 512,
+                "seed": 42,
+            },
+            InferenceProviderMapping(
+                provider="wavespeed",
+                hf_model_id="black-forest-labs/FLUX.1-schnell",
+                providerId="wavespeed-ai/flux-schnell",
+                task="text-to-image",
+                status="live",
+            ),
+        )
+        assert payload == {
+            "prompt": "a beautiful cat",
+            "num_inference_steps": 30,
+            "guidance_scale": 7.5,
+            "width": 512,
+            "height": 512,
+            "seed": 42,
+        }
+
+    def test_prepare_text_to_video_payload(self):
+        """Test payload preparation for text-to-video task."""
+        helper = WavespeedAITextToVideoTask()
+        payload = helper._prepare_payload_as_dict(
+            "a dancing cat",
+            {
+                "guidance_scale": 5,
+                "num_inference_steps": 30,
+                "seed": -1,
+                "duration": 5,
+                "enable_safety_checker": True,
+                "flow_shift": 2.9,
+                "size": "480*832",
+            },
+            InferenceProviderMapping(
+                provider="wavespeed",
+                hf_model_id="Wan-AI/Wan2.1-T2V-14B",
+                providerId="wavespeed-ai/wan-2.1/t2v-480p",
+                task="text-to-video",
+                status="live",
+            ),
+        )
+        assert payload == {
+            "prompt": "a dancing cat",
+            "guidance_scale": 5,
+            "num_inference_steps": 30,
+            "seed": -1,
+            "duration": 5,
+            "enable_safety_checker": True,
+            "flow_shift": 2.9,
+            "size": "480*832",
+        }
+
+    def test_prepare_image_to_image_payload(self, mocker):
+        """Test payload preparation for image-to-image task."""
+        helper = WavespeedAIImageToImageTask()
+
+        # Mock image data
+        image_data = b"dummy_image_data"
+        mock_encode = mocker.patch("base64.b64encode")
+        mock_encode.return_value.decode.return_value = "base64_encoded_image"
+
+        payload = helper._prepare_payload_as_dict(
+            image_data,
+            {"prompt": "The leopard chases its prey", "guidance_scale": 5, "num_inference_steps": 30, "seed": -1},
+            InferenceProviderMapping(
+                provider="wavespeed",
+                hf_model_id="HiDream-ai/HiDream-E1-Full",
+                providerId="wavespeed-ai/hidream-e1-full",
+                task="image-to-image",
+                status="live",
+            ),
+        )
+
+        assert payload == {
+            "image": "data:image/jpeg;base64,base64_encoded_image",
+            "prompt": "The leopard chases its prey",
+            "guidance_scale": 5,
+            "num_inference_steps": 30,
+            "seed": -1,
+        }
+        mock_encode.assert_called_once_with(image_data)
+
+    def test_prepare_image_to_video_payload(self, mocker):
+        """Test payload preparation for image-to-video task."""
+        helper = WavespeedAIImageToVideoTask()
+
+        # Mock image data
+        image_data = b"dummy_image_data"
+        mock_encode = mocker.patch("base64.b64encode")
+        mock_encode.return_value.decode.return_value = "base64_encoded_image"
+
+        payload = helper._prepare_payload_as_dict(
+            image_data,
+            {"prompt": "The leopard chases its prey", "guidance_scale": 5, "num_inference_steps": 30, "seed": -1},
+            InferenceProviderMapping(
+                provider="wavespeed",
+                hf_model_id="Wan-AI/Wan2.1-I2V-14B-480P",
+                providerId="wavespeed-ai/wan-2.1/i2v-480p",
+                task="image-to-video",
+                status="live",
+            ),
+        )
+
+        assert payload == {
+            "image": "data:image/jpeg;base64,base64_encoded_image",
+            "prompt": "The leopard chases its prey",
+            "guidance_scale": 5,
+            "num_inference_steps": 30,
+            "seed": -1,
+        }
+        mock_encode.assert_called_once_with(image_data)
+
+    def test_prepare_urls(self):
+        """Test URL preparation for different tasks."""
+        # Text to Image
+        t2i_helper = WavespeedAITextToImageTask()
+        t2i_url = t2i_helper._prepare_url("ws_test_key", "wavespeed-ai/flux-schnell")
+        assert t2i_url == "https://api.wavespeed.ai/api/v3/wavespeed-ai/flux-schnell"
+
+        # Text to Video
+        t2v_helper = WavespeedAITextToVideoTask()
+        t2v_url = t2v_helper._prepare_url("ws_test_key", "wavespeed-ai/wan-2.1/t2v-480p")
+        assert t2v_url == "https://api.wavespeed.ai/api/v3/wavespeed-ai/wan-2.1/t2v-480p"
+
+        # Image to Image
+        i2i_helper = WavespeedAIImageToImageTask()
+        i2i_url = i2i_helper._prepare_url("ws_test_key", "wavespeed-ai/hidream-e1-full")
+        assert i2i_url == "https://api.wavespeed.ai/api/v3/wavespeed-ai/hidream-e1-full"
+
+        # Image to Video
+        i2v_helper = WavespeedAIImageToVideoTask()
+        i2v_url = i2v_helper._prepare_url("ws_test_key", "wavespeed-ai/wan-2.1/i2v-480p")
+        assert i2v_url == "https://api.wavespeed.ai/api/v3/wavespeed-ai/wan-2.1/i2v-480p"
+
+
+class TestZaiProvider:
+    def test_prepare_route(self):
+        helper = ZaiConversationalTask()
+        route = helper._prepare_route("test-model", "zai_token")
+        assert route == "/api/paas/v4/chat/completions"
+
+    def test_prepare_headers(self):
+        helper = ZaiConversationalTask()
+        headers = helper._prepare_headers({}, "test_key")
+        assert headers["Accept-Language"] == "en-US,en"
+
+    def test_prepare_url(self):
+        helper = ZaiConversationalTask()
+        assert helper.task == "conversational"
+        url = helper._prepare_url("zai_token", "test-model")
+        assert url == "https://api.z.ai/api/paas/v4/chat/completions"
+
+        # Test with HF token (should route through HF proxy)
+        url = helper._prepare_url("hf_token", "test-model")
+        assert url.startswith("https://router.huggingface.co/zai-org")
+
+
 class TestBaseConversationalTask:
     def test_prepare_route(self):
         helper = BaseConversationalTask(provider="test-provider", base_url="https://api.test.com")
@@ -1430,7 +1987,7 @@ class TestBaseTextGenerationTask:
         ),
     ],
 )
-def test_recursive_merge(dict1: Dict, dict2: Dict, expected: Dict):
+def test_recursive_merge(dict1: dict, dict2: dict, expected: dict):
     initial_dict1 = dict1.copy()
     initial_dict2 = dict2.copy()
     assert recursive_merge(dict1, dict2) == expected
@@ -1464,12 +2021,12 @@ def test_recursive_merge(dict1: Dict, dict2: Dict, expected: Dict):
         ({"a": [None, {"x": None}]}, {"a": [None, {}]}),
     ],
 )
-def test_filter_none(data: Dict, expected: Dict):
+def test_filter_none(data: dict, expected: dict):
     """Test that filter_none removes None values from nested dictionaries."""
     assert filter_none(data) == expected
 
 
-def test_get_provider_helper_auto(mocker):
+def test_get_provider_helper_auto_non_conversational(mocker):
     """Test the 'auto' provider selection logic."""
 
     mock_provider_a_helper = mocker.Mock(spec=TaskProviderHelper)
@@ -1491,3 +2048,13 @@ def test_get_provider_helper_auto(mocker):
 
     PROVIDERS.pop("provider-a", None)
     PROVIDERS.pop("provider-b", None)
+
+
+def test_get_provider_helper_auto_conversational():
+    """Test the 'auto' provider selection logic for conversational task.
+
+    In practice, no HTTP call is made to the Hub because routing is done server-side.
+    """
+    helper = get_provider_helper(provider="auto", task="conversational", model="test-model")
+
+    assert isinstance(helper, AutoRouterConversationalTask)
